"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * @Author: Mr.Hope
 * @Date: 2019-11-23 18:48:57
 * @LastEditors: Mr.Hope
 * @LastEditTime: 2020-03-21 23:16:52
 * @Description: 多语言配置
 */
const config_1 = require("./config");
exports.checkLang = (lang) => config_1.langs.includes(lang);
/**
 * 获取语言对应路径
 *
 * @param lang 语言
 */
exports.lang2path = (lang) => {
    if (config_1.lang2PathConfig[lang])
        return config_1.lang2PathConfig[lang];
    console.error(`${lang} has no path config, and will return '/' instead.
    You can contribute to https://github.com/Mister-Hope/vuepress-theme-hope/blob/master/packages/shared-utils/src/i18n/config.ts`);
    return '/';
};
/**
 * 获取路径对应语言
 *
 * @param path 路径
 */
exports.path2lang = (path) => {
    if (config_1.path2langConfig[path])
        return config_1.path2langConfig[path];
    console.error(`${path} isn't assign with a lang, and will return 'en-US' instead.
    You can contribute to https://github.com/Mister-Hope/vuepress-theme-hope/blob/master/packages/shared-utils/src/i18n/config.ts`);
    return 'en-US';
};
/**
 * 获取特定语言的本地化文字
 *
 * @param lang
 */
exports.getLocale = (lang) => {
    if (config_1.localesConfig[lang])
        return config_1.localesConfig[lang];
    console.error(`${lang} locates config is missing, and will return 'en-US' instead.
    You can contribute to https://github.com/Mister-Hope/vuepress-theme-hope/blob/master/packages/shared-utils/src/i18n/config.ts`);
    return config_1.localesConfig['en-US'];
};
/** 获得默认多语言配置 */
exports.getDefaultLocale = () => config_1.localesConfig['en-US'];
const i18n = {
    checkLang: exports.checkLang,
    config: config_1.config,
    langs: config_1.langs,
    lang2path: exports.lang2path,
    path2lang: exports.path2lang,
    getDefaultLocale: exports.getDefaultLocale,
    getLocale: exports.getLocale
};
exports.default = i18n;
